@@ -49,8 +49,6 @@
 
 package com.openexchange.mobile.api.facade.auth;
 
-import com.openexchange.mobile.api.facade.configuration.HostConfiguration;
-
 import lombok.AccessLevel;
 import lombok.AllArgsConstructor;
 import lombok.NonNull;
@@ -80,18 +78,10 @@ public class LoginCredentials {
     @NonFinal
     String host;
 
-    @Wither
-    @NonFinal
-    String xHost;
-
     @Wither
     @NonFinal
     String forwardedFor;
 
-    @Wither
-    @NonFinal
-    String forwardedProto;
-
     @Wither
     @NonFinal
     String userAgent;
@@ -100,8 +90,4 @@ public class LoginCredentials {
     @NonFinal
     String trackingId;
 
-    @Wither
-    @NonFinal
-    HostConfiguration hostConfiguration;
-
 }
\ No newline at end of file
