@@ -58,6 +58,7 @@ import com.openexchange.mobile.api.facade.auth.impl.LogoutConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.AccountsConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.AllCapabilitiesConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.AllFoldersConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.AutoconfigureAccountConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ClearFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ConfigConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ContactsConnector;
@@ -84,6 +85,7 @@ import com.openexchange.mobile.api.facade.connectors.impl.UpdateAccountConnector
 import com.openexchange.mobile.api.facade.connectors.impl.UserConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ValidateAccountConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.VersionConnector;
+import com.openexchange.mobile.api.facade.endpoints.requests.AutoconfigData;
 import com.openexchange.mobile.api.facade.models.Folder;
 import com.openexchange.mobile.api.facade.models.MailAccountData;
 import com.openexchange.mobile.api.facade.models.MailFlags;
@@ -154,4 +156,6 @@ public interface ConnectorFactory {
 
     VersionConnector getVersionConnector();
 
+    AutoconfigureAccountConnector getAutoconfigureAccountConnector(SessionData sessionData, AutoconfigData autoconfigData);
+
 }
