@@ -61,7 +61,6 @@ import com.openexchange.mobile.api.facade.connectors.impl.ConfigConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.CreateFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.DeleteFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ExamineMultipleFoldersConnector;
-import com.openexchange.mobile.api.facade.connectors.impl.UpdateFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.responses.ConfigResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.ExamineResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.FoldersResponseMto;
@@ -74,7 +73,6 @@ import com.openexchange.mobile.api.facade.models.CreatedFolder;
 import com.openexchange.mobile.api.facade.models.ExamineResult;
 import com.openexchange.mobile.api.facade.models.Folder;
 import com.openexchange.mobile.api.facade.models.MailAccountData;
-import com.openexchange.mobile.api.facade.models.UpdatedFolder;
 import com.openexchange.mobile.api.facade.utils.ListUtil;
 import com.openexchange.mobile.api.facade.utils.MapFunction;
 
@@ -97,14 +95,6 @@ public class FoldersService {
         return new CreatedFolder(folderId, name);
     }
 
-    public UpdatedFolder updateFolder(SessionData sessionData, String folderId, String newParentFolderId, String newName) {
-        ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
-        UpdateFolderConnector connector = connectorFactory.getUpdateFolderConnector(sessionData, folderId, newParentFolderId, newName);
-        StringResponseMto response = connector.execute();
-        String newFolderId = UpdateFolderConnector.map(response);
-        return new UpdatedFolder(newFolderId);
-    }
-
     public void deleteFolder(SessionData sessionData, String folderId) {
         ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
         DeleteFolderConnector connector = connectorFactory.getDeleteFolderConnector(sessionData, folderId);
@@ -158,8 +148,6 @@ public class FoldersService {
         List<Folder> folders = retrieveFolders(connectorFactory, sessionData, account.getRootFolderId(), account.getArchiveFolderId(), language);
         if (!account.isPop3Account()) {
             examineFolders(connectorFactory, sessionData, folders);
-        } else {
-            examineResetFolders(folders);
         }
         account = account.withFolders(folders);
         adjustFolderParents(account, account.isPrimaryAccount() && isNamespaceSet);
@@ -213,16 +201,6 @@ public class FoldersService {
         return new ExamineResult(folderId, changed, newValidity, newNext);
     }
 
-    private void examineResetFolders(List<Folder> folders) {
-        for (int index = 0; index < folders.size(); index++) {
-            Folder folder = folders.get(index);
-            folder.setValidity(null);
-            folder.setNext(null);
-            folder.setTotal(-1);
-            folder.setUnread(-1);
-        }
-    }
-
     private void adjustFolderParents(Account account, boolean isNamespaceSet) {
         if (!isNamespaceSet) {
             return;
@@ -254,5 +232,4 @@ public class FoldersService {
             }
         }
     }
-
 }
