@@ -83,6 +83,7 @@ import org.apache.http.impl.client.BasicCookieStore;
 import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.impl.client.HttpClients;
 import org.apache.http.ssl.SSLContextBuilder;
+import org.apache.http.util.TextUtils;
 
 @UtilityClass
 public class RequestUtil {
@@ -113,33 +114,19 @@ public class RequestUtil {
 
     public static final String HEADER_X_FORWARDED_FOR = "X-Forwarded-For";
 
-    public static final String HEADER_X_FORWARDED_PROTO = "X-Forwarded-Proto";
-
     public static final String HEADER_HOST = "Host";
 
     public static final String HEADER_X_HOST = "X-Host";
 
     private static final int USER_AGENT_MAXLEN = 100;
 
-    private static final Pattern USER_AGENT_PATTERN = Pattern.compile("^(.*)\\.(.*)\\.Mail/(\\S*) \\(OS:(.*); device:(.*)\\)$");
-
-    private static final String HEADER_CACHE_CONTROL = "Cache-control";
-
-    private static final String HEADER_CACHE_CONTROL_VALUE = "no-cache, no-store, must-revalidate";
-
-    private static final String HEADER_EXPIRES = "Expires";
-
-    private static final String HEADER_EXPIRES_VALUE = "0";
-
-    private static final String HEADER_PRAGMA = "Pragma";
-
-    private static final String HEADER_PRAGMA_VALUE = "no-cache";
+    private static final Pattern USER_AGENT_PATTERN = Pattern.compile("^(.*)\\.(.*)\\.Mail/(\\S*) \\(.*\\)$");
 
     @SneakyThrows
     public RequestConfiguration createConfiguration() {
         BasicCookieStore cookieStore = new BasicCookieStore();
         RequestConfig requestConfig = RequestConfig.custom()
-                .setConnectTimeout(10000)
+                .setConnectTimeout(10_000)
                 .build();
         /* Java8: For Java 8:
         SSLContext sslContext = new SSLContextBuilder()
@@ -173,18 +160,16 @@ public class RequestUtil {
             throw ApiFacadeException.badRequest(ApiFacadeException.Code.MISSING_COOKIES, "Cookies missing");
         }
         String hostname = getHostHeader(request);
-        String xHostname = getXHostHeader(request);
         String userAgent = getUserAgent(request);
         String trackingId = getTrackingId(request);
         String contextId = getContextId(request);
         String userId = getUserId(request);
-        UserAgentInfo userAgentInfo = parseUserAgent(userAgent);
-        HostConfiguration hostConfiguration = ConfigurationHelper.getConfiguration(hostname, xHostname, userAgentInfo);
-        checkUserAgent(userAgentInfo, hostConfiguration);
-        return enhanceSessionData(request, hostConfiguration, hostname, xHostname, userAgent, trackingId, contextId, userId, new SessionData(session, cookies));
+        HostConfiguration hostConfiguration = ConfigurationHelper.getConfiguration(request);
+        checkUserAgent(userAgent, hostConfiguration);
+        return enhanceSessionData(request, hostConfiguration, hostname, userAgent, trackingId, contextId, userId, new SessionData(session, cookies));
     }
 
-    public static SessionData enhanceSessionData(HttpServletRequest request, HostConfiguration configuration, String hostname, String xHostname, String userAgent, String trackingId, String contextId, String userId, SessionData sessionData) {
+    public static SessionData enhanceSessionData(HttpServletRequest request, HostConfiguration configuration, String hostname, String userAgent, String trackingId, String contextId, String userId, SessionData sessionData) {
         if (trackingId != null) {
             sessionData.setProperty(SessionData.PROPERTY_TRACKING_ID, trackingId);
         }
@@ -194,15 +179,9 @@ public class RequestUtil {
         if (userId != null) {
             sessionData.setProperty(SessionData.PROPERTY_USER_ID, userId);
         }
-        Map<String, String> customProperties = configuration.getCustomProperties();
-        if (customProperties.size() > 0) {
-            sessionData.getProperties().putAll(customProperties);
-        }
         return sessionData
                 .withHost(hostname)
-                .withXHost(xHostname)
                 .withForwardedFor(getForwardedForWithRemoteIp(request))
-                .withForwardedProto(getForwardedProto(request))
                 .withUserAgent(userAgent)
                 .withConfiguration(configuration);
     }
@@ -215,7 +194,11 @@ public class RequestUtil {
         return userAgent;
     }
 
-    public void checkUserAgent(UserAgentInfo userAgentInfo, HostConfiguration hostConfiguration) {
+    public void checkUserAgent(String userAgent, HostConfiguration hostConfiguration) {
+        if (Strings.isEmpty(userAgent)) {
+            throw ApiFacadeException.missingHeader(HEADER_USER_AGENT);
+        }
+        UserAgentInfo userAgentInfo = parseUserAgent(userAgent);
         if (!hostConfiguration.isAllowedBrand(userAgentInfo.getBrand())) {
             throw ApiFacadeException.forbidden();
         }
@@ -235,7 +218,7 @@ public class RequestUtil {
         }
         Semver clientVersion = new Semver(clientVersionStr, SemverType.LOOSE);
         Semver minimumClientVersion = new Semver(minimumClientVersionStr, SemverType.LOOSE);
-        return minimumClientVersion.isLowerThanOrEqualTo(clientVersion);
+        return !clientVersion.isLowerThan(minimumClientVersion);
     }
 
     private String getMinimumClientVersion(Map<String, String> minimumClientVersions, UserAgentInfo userAgentInfo) {
@@ -258,13 +241,11 @@ public class RequestUtil {
     }
 
     public <T> Response jsonResponse(int statusCode, T responseBody) {
-        ResponseBuilder responseBuilder = Response.status(statusCode).entity(JacksonUtil.toString(responseBody));
-        return nonCachable(responseBuilder).build();
+        return Response.status(statusCode).entity(JacksonUtil.toString(responseBody)).build();
     }
 
     public Response emptyJsonResponse() {
-        ResponseBuilder responseBuilder = Response.ok().entity("{}");
-        return nonCachable(responseBuilder).build();
+        return Response.ok().entity("{}").build();
     }
 
     public <T> Response createCachableResponse(HttpServletRequest request, T responseBody) {
@@ -274,14 +255,7 @@ public class RequestUtil {
         boolean isNotModified = hashValue.equals(ifNoneMatchValue);
         ResponseBuilder responseBuilder = isNotModified ? Response.notModified() : Response.ok(responseBodyStr);
         responseBuilder.header(HEADER_ETAG, hashValue);
-        return nonCachable(responseBuilder).build();
-    }
-
-    public ResponseBuilder nonCachable(ResponseBuilder responseBuilder) {
-        responseBuilder.header(HEADER_CACHE_CONTROL, HEADER_CACHE_CONTROL_VALUE);
-        responseBuilder.header(HEADER_EXPIRES, HEADER_EXPIRES_VALUE);
-        responseBuilder.header(HEADER_PRAGMA, HEADER_PRAGMA_VALUE);
-        return responseBuilder;
+        return responseBuilder.build();
     }
 
     public String getRemoteIp(HttpServletRequest request) {
@@ -299,30 +273,21 @@ public class RequestUtil {
         return forwardedFor;
     }
 
-    public String getForwardedProto(HttpServletRequest request) {
-        return request.getHeader(HEADER_X_FORWARDED_PROTO);
-    }
-
     public UserAgentInfo parseUserAgent(String userAgent) {
-        if (Strings.isEmpty(userAgent)) {
-            throw ApiFacadeException.missingHeader(HEADER_USER_AGENT);
-        }
-        if (userAgent.length() > USER_AGENT_MAXLEN) {
+        if (TextUtils.isEmpty(userAgent) || userAgent.length() > USER_AGENT_MAXLEN) {
             throw ApiFacadeException.invalidUserAgent();
         }
         Matcher matcher = USER_AGENT_PATTERN.matcher(userAgent);
         if (!matcher.find()) {
             throw ApiFacadeException.invalidUserAgent();
         }
-        if (matcher.groupCount() != 5) {
+        if (matcher.groupCount() != 3) {
             throw ApiFacadeException.invalidUserAgent();
         }
         String brand = matcher.group(1);
         String platform = matcher.group(2);
         String clientVersion = matcher.group(3);
-        String osVersion = matcher.group(4).trim();
-        String device = matcher.group(5).trim();
-        return new UserAgentInfo(brand, platform, clientVersion, osVersion, device);
+        return new UserAgentInfo(brand, platform, clientVersion);
     }
 
     /*private*/ String getIfNoneMatch(HttpServletRequest request) {
@@ -334,11 +299,11 @@ public class RequestUtil {
     }
 
     public String getHostHeader(HttpServletRequest request) {
-        return request.getHeader(HEADER_HOST);
-    }
-
-    public String getXHostHeader(HttpServletRequest request) {
-        return request.getHeader(HEADER_X_HOST);
+        String value = request.getHeader(HEADER_X_HOST);
+        if (value == null) {
+            value = request.getHeader(HEADER_HOST);
+        }
+        return value;
     }
 
     public String getLanguage(HttpServletRequest request) {
